@@ -8,14 +8,13 @@ input point data.
 # License: BSD Style.
 
 # Enthought library imports.
-from enthought.traits.api import Instance, Trait, Bool, TraitPrefixList
+from enthought.traits.api import Instance, Trait, Bool
 from enthought.traits.api import Enum
 from enthought.traits.ui.api import View, Group, Item
 from enthought.tvtk.api import tvtk
 from enthought.tvtk.tvtk_base import TraitRevPrefixMap
 
 # Local imports.
-from enthought.mayavi.core.common import handle_children_state
 from enthought.mayavi.core.component import Component
 from enthought.mayavi.core.module import Module
 from enthought.mayavi.components import glyph_source
