@@ -55,6 +55,8 @@ def get_args(function):
 # `Engine` class
 ######################################################################
 class Engine(HasStrictTraits):
+    """ The Mayavi engine base class.
+    """
 
     # The version of this class.  Used for persistence.
     __version__ = 0
@@ -395,6 +397,10 @@ class Engine(HasStrictTraits):
         if scene in self._viewer_ref:
             del self._viewer_ref[scene]
 
+        # Clear the current scene if it has been removed.
+        if scene is self._current_scene:
+            self._current_scene = None
+
     @recordable
     def new_scene(self, viewer=None, name=None, **kwargs):
         """Create or manage a new VTK scene window.  If no `viewer`
