@@ -1,5 +1,6 @@
 from enthought.mayavi.tools.mlab_scene_model import MlabSceneModel
-from enthought.mayavi.core.ui.mayavi_scene import MayaviScene
+from enthought.mayavi.core.ui.mayavi_scene import MayaviScene, \
+                    DecoratedScene
 from enthought.tvtk.pyface.scene_editor import SceneEditor
 from enthought.mayavi.core.ui.engine_view import EngineView
 from enthought.mayavi.core.ui.engine_rich_view import EngineRichView
