@@ -2,7 +2,7 @@
 
 """
 # Author: Prabhu Ramachandran <prabhu_r@users.sf.net>
-# Copyright (c) 2005-2008, Enthought, Inc.
+# Copyright (c) 2005-2009, Enthought, Inc.
 # License: BSD Style.
 
 # Standard library imports.
@@ -24,7 +24,7 @@ from enthought.mayavi.core.base import Base
 from enthought.mayavi.core.adder_node import ModuleFilterAdderNode, \
         SourceAdderNode, ModuleAdderNode, FilterAdderNode, \
         SceneAdderNode, AdderNode
-from enthought.mayavi.action.help import open_help_index
+from enthought.mayavi.action.help import open_help_index, open_tvtk_docs
 
 class EngineViewHandler(Handler):
     """ A handler for the EngineView object. 
@@ -145,7 +145,7 @@ class EngineView(HasTraits):
                           auto_open=False,
                           copy=False,
                           delete=False,
-                          rename=False,
+                          rename=True,
                           ),
                  ObjectTreeNode(node_for=[Base],
                                 children='children_ui_list',
@@ -248,6 +248,16 @@ class EngineView(HasTraits):
                 perform=open_help_index,
             )
 
+        tvtk_docs = \
+            Action(
+                image=ImageResource('reader.png',
+                                            search_path=self._image_path),
+                tooltip="Search the VTK class browser",
+                defined_when='True',
+                enabled_when='True',
+                perform=open_tvtk_docs,
+            )
+
         record = \
             Action(
                 image=ImageResource('record.png',
@@ -260,14 +270,18 @@ class EngineView(HasTraits):
                 perform=self._perform_record,
             )
 
-        return [add_scene, add_source, add_module, add_filter, 
-                Separator(), help, record,]
+        # Check the record icon if the engine already has a recorder
+        # set.
+        if self.engine is not None and self.engine.recorder is not None:
+            record.checked = True
+
+        return [tvtk_docs, Separator(), add_scene, add_source, add_module, 
+                add_filter, Separator(), help, record]
 
 
     ###########################################################################
-    # private interface.
+    # Private interface.
     ###########################################################################
-
     def _perform_new_scene(self):
         self.engine.new_scene()
         self.engine.current_selection = self.engine.current_scene
@@ -284,7 +298,6 @@ class EngineView(HasTraits):
         adder = ModuleAdderNode(object=object)
         adder.edit_traits(view=adder.dialog_view())
 
-
     def _perform_add_filter(self):
         object = self.engine.current_selection
         if isinstance(object, AdderNode):
@@ -297,7 +310,27 @@ class EngineView(HasTraits):
         if e.recorder is None:
             start_recording(e, known=True, script_id='engine')
         else:
-            stop_recording(e)
+            stop_recording(e, save=False)
+
+    def _recorder_changed_for_engine(self, recorder):
+        """Called when the recorder trait on the engine trait of this
+        object changes.
+
+        This basically toggles the recording action when someone
+        attaches a recorder to the engine.
+        """
+        record_action = None
+        for action in self.actions:
+            if hasattr(action, 'tooltip') and \
+               action.tooltip.endswith('recording'):
+                record_action = action
+                break
+
+        if record_action is not None:
+            if recorder is not None:
+                record_action.checked = True
+            else:
+                record_action.checked = False
 
 
 ### EOF ######################################################################
