@@ -118,6 +118,16 @@ class TestMGlyphSource(unittest.TestCase):
         self.check_traits()
         self.check_dataset()
 
+    def test_strange_shape(self):
+        " Test the MGlyphSource with strange shapes for the arguments "
+        x, y, z, v, s, src = self.get_data()
+        x = y = z = v = s = 0
+        src.reset(x=x, y=y, z=z, u=v, v=v, w=v, scalars=None)
+        src.reset(x=x, y=y, z=z, u=v, v=v, w=v, scalars=s)       
+        x = y = z = v = s = 1
+        src.set(x=x, y=y, z=z, u=v, v=v, w=v, scalars=None) 
+        src.set(x=x, y=y, z=z, u=v, v=v, w=v, scalars=s)       
+
 
 ################################################################################
 # `TestMGlyphSource`
@@ -269,8 +279,8 @@ class TestMArraySource(unittest.TestCase):
         spacing = [dx, dy, dz]
         dimensions = (x.shape[0], y.shape[1], z.shape[2])
         ds = src.dataset
-        self.assertEqual(N.all(ds.origin == origin), True)
-        self.assertEqual(N.allclose(ds.spacing, spacing), True)
+        self.assertEqual(N.all(src.m_data.origin == origin), True)
+        self.assertEqual(N.allclose(src.m_data.spacing, spacing), True)
         self.assertEqual(N.allclose(ds.dimensions, dimensions), True)
 
         vec = src.dataset.point_data.vectors.to_array()
@@ -516,7 +526,7 @@ class TestMArray2DSource(unittest.TestCase):
         spacing = [dx, dy, 1]
         ds = src.dataset
         self.assertEqual(N.all(ds.origin == origin), True)
-        self.assertEqual(N.allclose(ds.spacing, spacing), True)
+        self.assertEqual(N.allclose(src.m_data.spacing, spacing), True)
               
         sc = src.dataset.point_data.scalars.to_array()      
         s1 = s.transpose()
@@ -805,6 +815,20 @@ class TestMTriangularMeshSource(unittest.TestCase):
 
         self.check_traits()
 
+    def test_changed_size(self):
+        """ Change the number of the points, and establish
+            to new points, to check that we don't get errors with the
+            dimensions of the scalars.
+        """
+        n = 100
+        _, _, _, _, _, src = self.get_data()
+        triangles = N.c_[N.arange(n-3),
+                            N.arange(n-3)+1,
+                            n-1-N.arange(n-3)]
+        x, y, z = N.random.random((3, n))
+        src.reset(x=x, y=y, z=z, triangles=triangles)
+
+
     def test_handlers(self):
         "Test if the various static handlers work correctly."
         x, y, z, triangles, s, src = self.get_data()
