@@ -19,6 +19,7 @@ import numpy as np
 from enthought.pyface.timer.api import do_later
 
 #  imports
+from enthought.tvtk.api import tvtk
 from enthought.mayavi.core.scene import Scene
 from enthought.mayavi.core.registry import registry
 from .camera import view
@@ -127,9 +128,11 @@ def clf(figure=None):
             scene = gcf()
         else:
             scene = figure
+        disable_render = scene.scene.disable_render
         scene.scene.disable_render = True
         scene.children[:] = []
-        scene.scene.disable_render = False
+        scene._mouse_pick_dispatcher.clear_callbacks()
+        scene.scene.disable_render = disable_render
     except AttributeError:
         pass
     gc.collect()
@@ -227,21 +230,25 @@ def savefig(filename, size=None, figure=None, magnification='auto',
     """
     if figure is None:
         figure = gcf()
-    current_x, current_y = tuple(figure.scene.get_size())
-    if size is None:
-        size = current_x, current_y
-    target_x, target_y = size
     current_mag = figure.scene.magnification
-    if magnification is 'auto':
-        magnification = max(target_x//current_x,
-                                     target_y//current_y) + 1
-        target_x = int(target_x/magnification)
-        target_y = int(target_y/magnification)
-    figure.scene.magnification = magnification
-    figure.scene.save(filename, 
-                        size=(target_x, target_y),
-                        **kwargs)
-    figure.scene.magnification = current_mag 
+    try:
+        if size is not None:
+            current_x, current_y = tuple(figure.scene.get_size())
+            target_x, target_y = size
+            if magnification is 'auto':
+                magnification = max(target_x//current_x,
+                                            target_y//current_y) + 1
+                target_x = int(target_x/magnification)
+                target_y = int(target_y/magnification)
+                size = target_x, target_y
+        elif magnification is 'auto':
+            magnification = 1
+        figure.scene.magnification = int(magnification)
+        figure.scene.save(filename, 
+                            size=size,
+                            **kwargs)
+    finally:
+        figure.scene.magnification = int(current_mag)
 
 
 def sync_camera(reference_figure, target_figure):
@@ -254,4 +261,78 @@ def sync_camera(reference_figure, target_figure):
             lambda: do_later(target_figure.scene.render))
 
 
+def screenshot(figure=None, mode='rgb', antialiased=False):
+    """ Return the current figure pixmap as an array.
+
+        **Parameters**
+
+        :figure: a figure instance or None, optional
+            If specified, the figure instance to capture the view of.
+        :mode: {'rgb', 'rgba'}
+            The color mode of the array captured.
+        :antialiased: {True, False}
+            Use anti-aliasing for rendering the screenshot.
+            Uses the number of aa frames set by 
+            figure.scene.anti_aliasing_frames
+
+        **Notes**
+
+        On most systems, this works similarly to taking a screenshot of
+        the rendering window. Thus if it is hidden by another window, you
+        will capture the other window. This limitation is due to the
+        heavy use of the hardware graphics system.
+
+        **Examples**
+
+        This function can be useful for integrating 3D plotting with
+        Mayavi in a 2D plot created by matplotlib.
+
+        >>> from enthought.mayavi import mlab
+        >>> mlab.test_plot3d()
+        >>> arr = mlab.screenshot()
+        >>> import pylab as pl
+        >>> pl.imshow(arr)
+        >>> pl.axis('off')
+        >>> pl.show()
+
+    """
+    if figure is None: 
+        figure = gcf()
+    x, y = tuple(figure.scene.get_size())
+
+    # Try to lift the window
+    figure.scene._lift()
+    if mode == 'rgb':
+        out = tvtk.UnsignedCharArray()
+        shape = (y, x, 3)
+        pixel_getter = figure.scene.render_window.get_pixel_data 
+        pg_args = (0, 0, x-1, y-1, 1, out)
+        
+    elif mode == 'rgba':
+        out = tvtk.FloatArray()
+        shape = (y, x, 4)
+        pixel_getter = figure.scene.render_window.get_rgba_pixel_data
+        pg_args = (0, 0, x-1, y-1, 1, out)        
+
+    else:
+        raise ValueError('mode type not understood')
+
+    if antialiased:
+        # save the current aa value to restore it later
+        old_aa = figure.scene.render_window.aa_frames
+
+        figure.scene.render_window.aa_frames = figure.scene.anti_aliasing_frames
+        figure.scene.render()
+        pixel_getter(*pg_args)
+        figure.scene.render_window.aa_frames = old_aa
+        figure.scene.render()
+
+    else:
+        pixel_getter(*pg_args)
+    
+    # Return the array in a way that pylab.imshow plots it right:
+    out = out.to_array()
+    out.shape = shape
+    out = np.flipud(out)
+    return out
 
