@@ -20,11 +20,13 @@ from sources import vector_scatter, vector_field, scalar_scatter, \
             scalar_field, line_source, array2d_source, grid_source, \
             triangular_mesh_source, vertical_vectors_source
 from filters import ExtractVectorNormFactory, WarpScalarFactory, \
-            TubeFactory, ExtractEdgesFactory, PolyDataNormalsFactory
+            TubeFactory, ExtractEdgesFactory, PolyDataNormalsFactory, \
+            StripperFactory
+from enthought.mayavi.core.scene import Scene
 from auto_doc import traits_doc, dedent
 import tools
 from enthought.traits.api import Array, Callable, CFloat, HasTraits, \
-    List, Trait, Any, Instance, TraitError
+    List, Trait, Any, Instance, TraitError, true
 import numpy
 
 def document_pipeline(pipeline):
@@ -60,6 +62,28 @@ class Pipeline(HasTraits):
                 help='Figure to populate.')
 
     def __call__(self, *args, **kwargs):
+        """ Calls the logics of the factory, but only after disabling 
+            rendering, if needed.
+        """
+        # First retrieve the scene, if any.
+        if 'figure' in kwargs:
+            figure = kwargs['figure']
+            assert isinstance(figure, (Scene, None))
+            scene = figure.scene
+        else:
+            scene = tools.gcf().scene
+        if scene is not None:
+            self._do_redraw = not scene.disable_render
+            scene.disable_render = True
+        # Then call the real logic
+        output = self.__call_internal__(*args, **kwargs)
+        # And re-enable the rendering, if needed.
+        if scene is not None:
+            scene.disable_render = not self._do_redraw
+        return output
+
+
+    def __call_internal__(self, *args, **kwargs):
         """ Builds the source and runs through the pipeline, returning
         the last object created by the pipeline."""
         self.store_kwargs(kwargs)
@@ -142,13 +166,13 @@ class Points3d(Pipeline):
                         'give the maximum glyph size in drawing units'
                         )
     
-    def __call__(self, *args, **kwargs):
+    def __call_internal__(self, *args, **kwargs):
         """ Override the call to be able to scale automaticaly the glyphs.
         """
         scale_factor =  kwargs.get('scale_factor', 'auto')
         if scale_factor == 'auto':
             kwargs['scale_factor'] = 1
-        g = Pipeline.__call__(self, *args, **kwargs)
+        g = Pipeline.__call_internal__(self, *args, **kwargs)
         if scale_factor == 'auto':
             g.glyph.glyph.scale_factor = \
                              tools._typical_distance(g.mlab_source.dataset)
@@ -326,7 +350,7 @@ class Flow(Pipeline):
 
     _pipeline = [ExtractVectorNormFactory, StreamlineFactory, ] 
 
-    def __call__(self, *args, **kwargs):
+    def __call_internal__(self, *args, **kwargs):
         """ Override the call to be able to choose whether to apply an
         ExtractVectorNorm filter.
         """
@@ -481,7 +505,6 @@ def test_contour3d_anim():
         ms.scalars = x*x*0.5 + y*x*0.1*(i+1) + z*z*0.25
     return obj
 
-
 ############################################################################# 
 class Plot3d(Pipeline):
     """
@@ -504,9 +527,9 @@ class Plot3d(Pipeline):
 
     _source_function = Callable(line_source)
 
-    _pipeline = [TubeFactory, SurfaceFactory, ]
+    _pipeline = [StripperFactory, TubeFactory, SurfaceFactory, ]
 
-    def __call__(self, *args, **kwargs):
+    def __call_internal__(self, *args, **kwargs):
         """ Override the call to be able to choose whether to apply
         filters.
         """
@@ -517,6 +540,7 @@ class Plot3d(Pipeline):
         self.pipeline = self._pipeline[:]
         if self.kwargs['tube_radius'] == None:
             self.pipeline.remove(TubeFactory)
+            self.pipeline.remove(StripperFactory)
         return self.build_pipeline()
 
 
@@ -643,7 +667,7 @@ class Surf(Pipeline):
 
     mask = Array(help="boolean mask array to suppress some data points.")
 
-    def __call__(self, *args, **kwargs):
+    def __call_internal__(self, *args, **kwargs):
         """ Override the call to be able to scale automaticaly the axis.
         """
         self.source = self._source_function(*args, **kwargs)
@@ -750,8 +774,11 @@ class Mesh(Pipeline):
     the vertices of the surface. The connectivity between these points is
     implied by the connectivity on the arrays. 
 
-    For simple structures (such as orthogonal grids) prefer the surf function,
-    as it will create more efficient data structures."""
+    For simple structures (such as orthogonal grids) prefer the `surf` function,
+    as it will create more efficient data structures. For mesh defined by
+    triangles rather than regular implicit connectivity, see the 
+    `triangular_mesh` function.
+    """
 
     scale_mode = Trait('none', {'none':'data_scaling_off',
                                 'scalar':'scale_by_scalar',
@@ -781,7 +808,7 @@ class Mesh(Pipeline):
     _pipeline = [ExtractEdgesFactory, GlyphFactory, TubeFactory, 
                         SurfaceFactory]
     
-    def __call__(self, *args, **kwargs):
+    def __call_internal__(self, *args, **kwargs):
         """ Override the call to be able to choose whether to apply
         filters.
         """
@@ -970,14 +997,18 @@ class BarChart(Pipeline):
     lateral_scale = CFloat(0.9, desc='The lateral scale of the glyph, '
                 'in units of the distance between nearest points')
 
-    def __call__(self, *args, **kwargs):
+    auto_scale = true(desc='whether to compute automaticaly the '
+                           'lateral scaling of the glyphs. This might be '
+                           'computationaly expensive.')
+
+    def __call_internal__(self, *args, **kwargs):
         """ Override the call to be able to scale automaticaly the axis.
         """
-        g = Pipeline.__call__(self, *args, **kwargs)
+        g = Pipeline.__call_internal__(self, *args, **kwargs)
         gs = g.glyph.glyph_source
         # Use a cube source for glyphs.
         if not 'mode' in kwargs:
-            gs.glyph_source = gs.glyph_list[-1]
+            gs.glyph_source = gs.glyph_dict['cube_source']
         # Position the glyph tail on the point.
         gs.glyph_position = 'tail'
         gs.glyph_source.center = (0.0, 0.0, 0.5)
@@ -987,9 +1018,16 @@ class BarChart(Pipeline):
         if not 'scale_mode' in kwargs:
             g.glyph.scale_mode = 'scale_by_vector_components'
         g.glyph.glyph.clamping = False
-        x, y, z = g.mlab_source.x, g.mlab_source.y, g.mlab_source.z
-        scale_factor = g.glyph.glyph.scale_factor* \
+        # The auto-scaling code. It involves finding the minimum
+        # distance between points, which can be very expensive. We
+        # shortcut this calculation for structured data
+        if len(args) == 1 or self.auto_scale:
+            min_axis_distance = 1
+        else:
+            x, y, z = g.mlab_source.x, g.mlab_source.y, g.mlab_source.z
+            min_axis_distance = \
                     tools._min_axis_distance(x, y, z)
+        scale_factor = g.glyph.glyph.scale_factor * min_axis_distance
         lateral_scale = kwargs.pop('lateral_scale', self.lateral_scale)
         try:
             g.glyph.glyph_source.glyph_source.y_length = \
