@@ -161,7 +161,7 @@ class PopupScene(object):
             rw.SetNextWindowInfo(str(widget.GetHandle()))
             rw.WindowRemap()
         vc.Reparent(widget)
-        wx.Yield()
+        wx.GetApp().Yield(True)
         # Restore the original render.
         vc.Render = orig_render
         vc.Render()
@@ -526,6 +526,11 @@ class Scene(TVTKScene, Widget):
 
         # Call the original handler (this will Show the widget)
         self._vtk_control.OnPaint(event)
+        if len(self.renderer.lights) == 0:
+            # The renderer is not ready yet, we do not do anything, and
+            # we do not remove this callback, so that it will be called
+            # later.
+            return
         # Now create the light manager.
         self.light_manager = light_manager.LightManager(self)
 
@@ -629,7 +634,7 @@ class Scene(TVTKScene, Widget):
             window.SetSize(parent.GetSize())
             # This is necessary on slow machines in order to force the
             # wx events to be handled.
-            wx.Yield()
+            wx.GetApp().Yield(True)
             window.Render()
 
         if wx.Platform == '__WXMSW__':
@@ -676,7 +681,7 @@ class Scene(TVTKScene, Widget):
             w = w.GetParent()
         if w:
             w.Raise()
-            wx.Yield()
+            wx.GetApp().Yield(True)
             self.render()
 
     def _start_event_callback(self, obj, event):
